@@ -1,6 +1,6 @@
 from typing import Any
 
-from pydantic import AnyHttpUrl, BaseSettings, SecretStr, ValidationError
+from pydantic import AnyHttpUrl, BaseSettings, SecretStr, ValidationError, validator
 
 from parble.exceptions import ConfigurationError
 
@@ -26,5 +26,11 @@ class Settings(BaseSettings):
             msg = f"missing or incorrect settings value for {', '.join([' '.join(x['loc']) for x in e.errors()])}"
             raise ConfigurationError(msg) from e
 
+    @validator("url")
+    def url_ends_with_slash(cls, v):
+        if v[-1] != "/":
+            v += "/"
+        return v
+
 
 __all__ = ("Settings",)
